<?php
/**
 * Recent Articles Section options
 *
 * @package Theme Palace
 * @subpackage Blog Page Pro
 * @since Blog Page Pro 1.0.0
 */

// Add Recent Articles section
$wp_customize->add_section( 'blog_page_pro_recent_articles_section', array(
	'title'             => esc_html__( 'Recent Articles','blog-page-pro' ),
	'description'       => esc_html__( 'Recent Articles Section options.', 'blog-page-pro' ),
	'panel'             => 'blog_page_pro_front_page_panel',
) );

// Recent Articles content enable control and setting
$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_section_enable]', array(
	'default'			=> 	$options['recent_articles_section_enable'],
	'sanitize_callback' => 'blog_page_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Page_Pro_Switch_Control( $wp_customize, 'blog_page_pro_theme_options[recent_articles_section_enable]', array(
	'label'             => esc_html__( 'Recent Articles Section Enable', 'blog-page-pro' ),
	'section'           => 'blog_page_pro_recent_articles_section',
	'on_off_label' 		=> blog_page_pro_switch_options(),
) ) );

// recent articles title setting and control
$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_articles_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blog_page_pro_theme_options[recent_articles_title]', array(
	'label'           	=> esc_html__( 'Title', 'blog-page-pro' ),
	'section'        	=> 'blog_page_pro_recent_articles_section',
	'active_callback' 	=> 'blog_page_pro_is_recent_articles_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_page_pro_theme_options[recent_articles_title]', array(
		'selector'            => '#recent .section-header h2.section-title',
		'settings'            => 'blog_page_pro_theme_options[recent_articles_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blog_page_pro_recent_articles_title_partial',
    ) );
}

// recent articles subtitle setting and control
$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_articles_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blog_page_pro_theme_options[recent_articles_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'blog-page-pro' ),
	'section'        	=> 'blog_page_pro_recent_articles_section',
	'active_callback' 	=> 'blog_page_pro_is_recent_articles_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_page_pro_theme_options[recent_articles_subtitle]', array(
		'selector'            => '#recent .section-header p.section-subtitle',
		'settings'            => 'blog_page_pro_theme_options[recent_articles_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blog_page_pro_recent_articles_subtitle_partial',
    ) );
}

// recent articles content type control and setting
$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_column]', array(
	'default'          	=> $options['recent_articles_column'],
	'sanitize_callback' => 'blog_page_pro_sanitize_select',
) );

$wp_customize->add_control( 'blog_page_pro_theme_options[recent_articles_column]', array(
	'label'             => esc_html__( 'Column Layout', 'blog-page-pro' ),
	'section'           => 'blog_page_pro_recent_articles_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blog_page_pro_is_recent_articles_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'blog-page-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'blog-page-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'blog-page-pro' ),
	),
) );

// Recent Articles content type control and setting
$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_content_type]', array(
	'default'          	=> $options['recent_articles_content_type'],
	'sanitize_callback' => 'blog_page_pro_sanitize_select',
) );

$wp_customize->add_control( 'blog_page_pro_theme_options[recent_articles_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'blog-page-pro' ),
	'section'           => 'blog_page_pro_recent_articles_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blog_page_pro_is_recent_articles_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'blog-page-pro' ),
		'post' 		=> esc_html__( 'Post', 'blog-page-pro' ),
		'category' 	=> esc_html__( 'Category', 'blog-page-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_count]', array(
	'default'          	=> $options['recent_articles_count'],
	'sanitize_callback' => 'blog_page_pro_sanitize_number_range',
	'validate_callback' => 'blog_page_pro_validate_recent_articles_count',
) );

$wp_customize->add_control( 'blog_page_pro_theme_options[recent_articles_count]', array(
	'label'             => esc_html__( 'Number of Recent Articles', 'blog-page-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'blog-page-pro' ),
	'section'           => 'blog_page_pro_recent_articles_section',
	'active_callback'   => 'blog_page_pro_is_recent_articles_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['recent_articles_count']; $i++ ) :

	// recent articles pages drop down chooser control and setting
	$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_content_page_' . $i . ']', array(
		'sanitize_callback' => 'blog_page_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blog_Page_Pro_Dropdown_Chooser( $wp_customize, 'blog_page_pro_theme_options[recent_articles_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'blog-page-pro' ), $i ),
		'section'           => 'blog_page_pro_recent_articles_section',
		'choices'			=> blog_page_pro_page_choices(),
		'active_callback'	=> 'blog_page_pro_is_recent_articles_section_content_page_enable',
	) ) );

	// recent articles posts drop down chooser control and setting
	$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_content_post_' . $i . ']', array(
		'sanitize_callback' => 'blog_page_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Blog_Page_Pro_Dropdown_Chooser( $wp_customize, 'blog_page_pro_theme_options[recent_articles_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'blog-page-pro' ), $i ),
		'section'           => 'blog_page_pro_recent_articles_section',
		'choices'			=> blog_page_pro_post_choices(),
		'active_callback'	=> 'blog_page_pro_is_recent_articles_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'blog_page_pro_theme_options[recent_articles_content_category]', array(
	'sanitize_callback' => 'blog_page_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Blog_Page_Pro_Dropdown_Taxonomies_Control( $wp_customize,'blog_page_pro_theme_options[recent_articles_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'blog-page-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'blog-page-pro' ),
	'section'           => 'blog_page_pro_recent_articles_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'blog_page_pro_is_recent_articles_section_content_category_enable'
) ) );

// recent articles title setting and control
$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_articles_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blog_page_pro_theme_options[recent_articles_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'blog-page-pro' ),
	'section'        	=> 'blog_page_pro_recent_articles_section',
	'active_callback' 	=> 'blog_page_pro_is_recent_articles_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_page_pro_theme_options[recent_articles_btn_title]', array(
		'selector'            => '#recent #infinite-handle a.btn',
		'settings'            => 'blog_page_pro_theme_options[recent_articles_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blog_page_pro_recent_articles_btn_title_partial',
    ) );
}

// recent articles title setting and control
$wp_customize->add_setting( 'blog_page_pro_theme_options[recent_articles_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'blog_page_pro_theme_options[recent_articles_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'blog-page-pro' ),
	'section'        	=> 'blog_page_pro_recent_articles_section',
	'active_callback' 	=> 'blog_page_pro_is_recent_articles_section_enable',
	'type'				=> 'url',
) );