<?php
/**
 * Popular Articles section
 *
 * This is the template for the content of popular articles section
 *
 * @package Theme Palace
 * @subpackage Blog Page Pro
 * @since Blog Page Pro 1.0.0
 */
if ( ! function_exists( 'blog_page_pro_add_popular_articles_section' ) ) :
    /**
    * Add popular articles section
    *
    *@since Blog Page Pro 1.0.0
    */
    function blog_page_pro_add_popular_articles_section() {
    	$options = blog_page_pro_get_theme_options();
        // Check if popular articles is enabled on frontpage
        $popular_articles_enable = apply_filters( 'blog_page_pro_section_status', true, 'popular_articles_section_enable' );

        if ( true !== $popular_articles_enable ) {
            return false;
        }
        // Get popular articles section details
        $section_details = array();
        $section_details = apply_filters( 'blog_page_pro_filter_popular_articles_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
 
        // Render popular articles section now.
        blog_page_pro_render_popular_articles_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_page_pro_get_popular_articles_section_details' ) ) :
    /**
    * popular articles section details.
    *
    * @since Blog Page Pro 1.0.0
    * @param array $input popular articles section details.
    */
    function blog_page_pro_get_popular_articles_section_details( $input ) {
        $options = blog_page_pro_get_theme_options();

        // Content type.
        $popular_articles_content_type  = $options['popular_articles_content_type'];
        $popular_articles_count = ! empty( $options['popular_articles_count'] ) ? $options['popular_articles_count'] : 4;
        
        $content = array();
        switch ( $popular_articles_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_articles_count; $i++ ) {
                    if ( ! empty( $options['popular_articles_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_articles_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_articles_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_articles_count; $i++ ) {
                    if ( ! empty( $options['popular_articles_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_articles_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_articles_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_articles_content_category'] ) ? $options['popular_articles_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_articles_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['author']    = blog_page_pro_author();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : '';
                    $page_post['large_image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular articles section content details.
add_filter( 'blog_page_pro_filter_popular_articles_section_details', 'blog_page_pro_get_popular_articles_section_details' );


if ( ! function_exists( 'blog_page_pro_render_popular_articles_section' ) ) :
  /**
   * Start popular articles section
   *
   * @return string popular articles content
   * @since Blog Page Pro 1.0.0
   *
   */
   function blog_page_pro_render_popular_articles_section( $content_details = array() ) {
        $options = blog_page_pro_get_theme_options();
        $popular_articles_content_type = $options['popular_articles_content_type'];
        $column = ! empty( $options['popular_articles_column'] ) ? $options['popular_articles_column'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="popular-post" class="page-section">
            <div class="wrapper">
                <div class="header-wrapper clear">
                    <?php if ( ! empty( $options['popular_articles_title'] ) || ! empty( $options['popular_articles_subtitle'] ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $options['popular_articles_title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $options['popular_articles_title'] ); ?></h2>
                            <?php endif; 

                            if ( ! empty( $options['popular_articles_subtitle'] ) ) : ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['popular_articles_subtitle'] ); ?></p>
                            <?php endif; ?>
                            <div class="seperator"></div>
                        </div><!-- .section-header -->
                    <?php endif; 

                    if ( ! empty( $options['popular_articles_btn_title'] ) && ! empty( $options['popular_articles_btn_url'] ) ) : ?>
                        <a href="<?php echo esc_url( $options['popular_articles_btn_url'] ); ?>" class="more-link">
                            <?php 
                                echo esc_html( $options['popular_articles_btn_title'] ) . ' '; 
                                echo blog_page_pro_get_svg( array( 'icon' => 'right' ) )
                            ?>
                        </a>
                    <?php endif; ?>
                </div><!-- .header-wrapper -->

                <div class="post-archive half col-2">
                    <?php $i = 1; 
                    $count = count( $content_details );
                    foreach ( $content_details as $content ) : 
                        if ( $i == 1 ) : ?>
                            <article class="hentry <?php echo ! empty( $content['large_image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                                <?php if ( ! empty( $content['large_image'] ) ) : ?>
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url( $content['large_image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                    </div>
                                <?php endif; ?>

                                <div class="entry-container">
                                    <?php if ( 'page' !== $popular_articles_content_type ) : ?>
                                        <span class="cat-links">
                                            <?php the_category( ', ', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->
                                    <?php endif; ?>
                                 
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <?php if ( 'page' !== $popular_articles_content_type ) : ?>
                                        <div class="entry-meta">
                                            <?php  
                                                echo wp_kses_post( $content['author'] );
                                                blog_page_pro_posted_on( $content['id'] );
                                            ?>
                                        </div><!-- .entry-meta -->
                                    <?php endif; ?>
                                </div>
                            </article>
                        <?php endif; 

                        if ( $i == 2 ) : ?>
                            <article class="hentry">
                                <ul>
                        <?php endif; 

                        if ( $i > 1 ) : ?>
                                <li>
                                    <?php if ( ! empty( $content['image'] ) ) : ?>
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                    <?php endif;

                                    if ( 'page' !== $popular_articles_content_type ) : ?>
                                        <div class="entry-meta">
                                            <?php  
                                                the_category( ', ', '', $content['id'] );
                                                blog_page_pro_posted_on( $content['id'] );
                                            ?>
                                        </div><!-- .entry-meta -->
                                    <?php endif; ?>

                                    <h3><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h3>
                                </li>

                        <?php endif; 

                        if ( $i > 1 && $i == $count ) : ?>
                                </ul>
                           </article>
                        <?php endif; 
                    $i++; 
                    endforeach; ?>
                </div><!-- .post-archive -->
            </div><!-- .wrapper -->
        </div><!-- #popular-post -->

        <?php if ( ! empty( $options['popular_articles_image'] ) && ! empty( $options['popular_articles_image_url'] ) ) : ?>
            <div id="advertisement">
                <div class="wrapper">
                    <a href="<?php echo esc_url( $options['popular_articles_image_url'] ); ?>"><img src="<?php echo esc_url( $options['popular_articles_image'] ); ?>"></a>
                </div><!-- .wrapper -->
            </div><!-- .advertisement -->
        <?php endif; ?>
    <?php }
endif;