<?php
/**
 * Recent Articles section
 *
 * This is the template for the content of recent articles section
 *
 * @package Theme Palace
 * @subpackage Blog Page Pro
 * @since Blog Page Pro 1.0.0
 */
if ( ! function_exists( 'blog_page_pro_add_recent_articles_section' ) ) :
    /**
    * Add recent articles section
    *
    *@since Blog Page Pro 1.0.0
    */
    function blog_page_pro_add_recent_articles_section() {
    	$options = blog_page_pro_get_theme_options();
        // Check if recent articles is enabled on frontpage
        $recent_articles_enable = apply_filters( 'blog_page_pro_section_status', true, 'recent_articles_section_enable' );

        if ( true !== $recent_articles_enable ) {
            return false;
        }
        // Get recent articles section details
        $section_details = array();
        $section_details = apply_filters( 'blog_page_pro_filter_recent_articles_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent articles section now.
        blog_page_pro_render_recent_articles_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_page_pro_get_recent_articles_section_details' ) ) :
    /**
    * recent articles section details.
    *
    * @since Blog Page Pro 1.0.0
    * @param array $input recent articles section details.
    */
    function blog_page_pro_get_recent_articles_section_details( $input ) {
        $options = blog_page_pro_get_theme_options();

        // Content type.
        $recent_articles_content_type  = $options['recent_articles_content_type'];
        $recent_articles_count = ! empty( $options['recent_articles_count'] ) ? $options['recent_articles_count'] : 4;
        
        $content = array();
        switch ( $recent_articles_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $recent_articles_count; $i++ ) {
                    if ( ! empty( $options['recent_articles_content_page_' . $i] ) )
                        $page_ids[] = $options['recent_articles_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_articles_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $recent_articles_count; $i++ ) {
                    if ( ! empty( $options['recent_articles_content_post_' . $i] ) )
                        $post_ids[] = $options['recent_articles_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $recent_articles_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['recent_articles_content_category'] ) ? $options['recent_articles_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $recent_articles_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['author']    = blog_page_pro_author();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent articles section content details.
add_filter( 'blog_page_pro_filter_recent_articles_section_details', 'blog_page_pro_get_recent_articles_section_details' );


if ( ! function_exists( 'blog_page_pro_render_recent_articles_section' ) ) :
  /**
   * Start recent articles section
   *
   * @return string recent articles content
   * @since Blog Page Pro 1.0.0
   *
   */
   function blog_page_pro_render_recent_articles_section( $content_details = array() ) {
        $options = blog_page_pro_get_theme_options();
        $recent_articles_content_type = $options['recent_articles_content_type'];
        $column = ! empty( $options['recent_articles_column'] ) ? $options['recent_articles_column'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="recent" class="page-section no-padding-top">
            <div class="wrapper">
                <?php if ( ! empty( $options['recent_articles_title'] ) || ! empty( $options['recent_articles_subtitle'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['recent_articles_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['recent_articles_title'] ); ?></h2>
                        <?php endif; 

                        if ( ! empty( $options['recent_articles_subtitle'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['recent_articles_subtitle'] ); ?></p>
                        <?php endif; ?>
                        <div class="seperator"></div>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div id="infinite-post-wrap" class="post-archive half grid <?php echo esc_attr( $column ); ?>">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article class="grid-item hentry <?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail popular">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="post-thumbnail">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                </div><!-- .post-thumbnail -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <?php if ( 'page' !== $recent_articles_content_type ) : ?>
                                    <span class="cat-links">
                                        <?php the_category( ', ', '', $content['id'] ); ?>
                                    </span>
                                <?php endif; ?>
                             
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( 'page' !== $recent_articles_content_type ) : ?>
                                    <div class="entry-meta">
                                        <?php  
                                            echo wp_kses_post( $content['author'] );
                                            blog_page_pro_posted_on( $content['id'] );
                                        ?>
                                    </div><!-- .entry-meta -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- #infinite-post-wrap -->

                <?php if ( ! empty( $options['recent_articles_btn_title'] ) && ! empty( $options['recent_articles_btn_url'] ) ) : ?>
                    <div id="infinite-handle">
                        <a href="<?php echo esc_url( $options['recent_articles_btn_url'] ); ?>" class="btn"><?php echo esc_html( $options['recent_articles_btn_title'] ); ?></a>
                    </div><!-- #infinite-handle -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #recent -->
        
    <?php }
endif;